#! /usr/bin/python
# Copyright (c) 2009, Willow Garage, Inc.
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the Willow Garage, Inc. nor the names of its
#       contributors may be used to endorse or promote products derived from
#       this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

# Author: Stuart Glaser

import time
import fcntl
from math import pi

import roslib
roslib.load_manifest('infinity_pedals')
import rospy
from joy.msg import *

import atexit
atexit.register(rospy.signal_shutdown, 'exit')

rospy.init_node('infinity_pedals', disable_signals=True)

pub_joy = rospy.Publisher(rospy.get_name() + '/joy', Joy)

def main():
    device = '/dev/hidraw1'
    try:
        device = rospy.get_param(rospy.get_name() + '/device')
    except:
        rospy.logerr("No device given: %s" % rospy.get_name())
        return

    with open(device, 'rb') as fhid:
        while True:
            buf = fhid.read(2)
            input = [ord(c) for c in buf]
            msg = Joy(buttons = [0] * 3)
            for i in range(3):
                if (1<<i) & input[0] != 0:
                    msg.buttons[i] = True
            pub_joy.publish(msg)

if __name__ == '__main__':
    try:
        main()
    except KeyboardInterrupt:
        pass
