#! /usr/bin/env python
# Copyright (c) 2009, Willow Garage, Inc.
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the Willow Garage, Inc. nor the names of its
#       contributors may be used to endorse or promote products derived from
#       this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.


import roslib
roslib.load_manifest('teleop_microscribe')
import rospy
from joy.msg import *
from std_srvs.srv import *

class Clutcher:
    def __init__(self, ms, teleop):
        self.engage = rospy.ServiceProxy("/%s/engage" % teleop, Empty)
        self.disengage = rospy.ServiceProxy("/%s/disengage" % teleop, Empty)
        rospy.Subscriber("/%s/buttons" % ms, Joy, self.buttons_cb)
        self.last_pushed = False
        self.engaged = False

    def buttons_cb(self, msg):
        pushed = False
        for b in msg.buttons:
            if b > 0:
                pushed = True
        if pushed and not self.last_pushed:
            if self.engaged:
                self.disengage()
                print "Disengaged:", self.disengage.resolved_name
                self.engaged = False
            else:
                self.engage()
                print "Engaged:", self.engage.resolved_name
                self.engaged = True
        self.last_pushed = pushed
            
rospy.init_node('button_clutch')
cl = Clutcher("microscribe_l", "teleop_microscribe_l")
cr = Clutcher("microscribe_r", "teleop_microscribe_r")
rospy.spin()
