#! /usr/bin/env python
# Copyright (c) 2009, Willow Garage, Inc.
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the Willow Garage, Inc. nor the names of its
#       contributors may be used to endorse or promote products derived from
#       this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.


import roslib
roslib.load_manifest('teleop_microscribe')
import rospy
from joy.msg import *
from pr2_controllers_msgs.msg import *
import actionlib.action_client

rospy.init_node('gripper_pedals')

class PedalGripper:
    CLOSED = 0
    OPENNING = 1
    OPEN = 2
    CLOSING = 3
    def __init__(self, pedal_topic, pedal_button, gripper_action):
        self.state = self.CLOSED
        self.gripper_client = actionlib.action_client.ActionClient(
            gripper_action, Pr2GripperCommandAction)
        self.pedal_button = pedal_button

        rospy.Subscriber(pedal_topic, Joy, self.pedal_cb)

    def pedal_cb(self, msg):
        b = msg.buttons[self.pedal_button]
        #print "CB", self.state, b

        if self.state is self.CLOSED and b:
            self.state = self.OPENNING
            self.gripper_client.send_goal(Pr2GripperCommandGoal(
                    command = Pr2GripperCommand(0.4, -1.0)))
        elif self.state is self.OPENNING and not b:
            self.state = self.OPEN
            self.gripper_client.send_goal(Pr2GripperCommandGoal(
                    command = Pr2GripperCommand(0.4, 0.0)))
        elif self.state is self.OPEN and b:
            self.state = self.CLOSING
            self.gripper_client.send_goal(Pr2GripperCommandGoal(
                    command = Pr2GripperCommand(0.0, -1.0,)))
        elif self.state is self.CLOSING and not b:
            self.state = self.CLOSED

def main():
    l = PedalGripper('/r_pedals/joy', 0, '/l_gripper_controller/gripper_action')
    r = PedalGripper('/r_pedals/joy', 2, '/r_gripper_controller/gripper_action')
    rospy.spin()

    
if __name__ == '__main__':
    main()
