#! /usr/bin/env python
# Copyright (c) 2009, Willow Garage, Inc.
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the Willow Garage, Inc. nor the names of its
#       contributors may be used to endorse or promote products derived from
#       this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.


import roslib
roslib.load_manifest('teleop_microscribe')
import rospy
from joy.msg import *
from pr2_controllers_msgs.msg import *
from trajectory_msgs.msg import *
from pr2_cockpit_msgs.srv import *

rospy.init_node('pedal_mode_switcher')

HEAD_PEDALS = 'head_pedals'
DRIVE_PEDALS = 'drive_pedals'

enabled = [HEAD_PEDALS]
all = {}

def send():
    global all, enabled
    for k, v in all.items():
        req = k in enabled
        print "Setting", k, "to", req
        try:
            v.call(req)
        except rospy.ServiceException, ex:
            print ex

def pedal_cb(msg):
    global enabled
    if msg.buttons[0]:
        enabled = [HEAD_PEDALS]
    elif msg.buttons[1]:
        enabled = [DRIVE_PEDALS]

    print "Enabled:", enabled
    send()

def setup():
    global all, enabled
    all[HEAD_PEDALS] = rospy.ServiceProxy('/head_pedals/enable', Enable)
    all[DRIVE_PEDALS] = rospy.ServiceProxy('/teleop_base_pedals/enable', Enable)
    rospy.Subscriber('/l_pedals/joy', Joy, pedal_cb)
    send()
    
def main():
    rate = rospy.Rate(1.0)
    setup()
    while not rospy.is_shutdown():
        send()
        rate.sleep()

    
if __name__ == '__main__':
    main()
